<?php

namespace Moblyze\Plan\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Moblyze\Plan\Interfaces\PassengerRepositoryInterface;

class PassengerPublicController extends BaseController
{
    // use PassengerWorkflow;

    /**
     * Constructor.
     *
     * @param type \Moblyze\Passenger\Interfaces\PassengerRepositoryInterface $passenger
     *
     * @return type
     */
    public function __construct(PassengerRepositoryInterface $passenger)
    {
        $this->repository = $passenger;
        parent::__construct();
    }

    /**
     * Show passenger's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $passengers = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('plan::passenger.names'))
            ->view('plan::public.passenger.index')
            ->data(compact('passengers'))
            ->output();
    }


    /**
     * Show passenger.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $passenger = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($passenger->name . trans('plan::passenger.name'))
            ->view('plan::public.passenger.show')
            ->data(compact('passenger'))
            ->output();
    }

}
