<?php

namespace Moblyze\Plan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Plan\Models\Manager;

class ManagerPolicy
{

    /**
     * Determine if the given user can view the manager.
     *
     * @param UserPolicy $user
     * @param Manager $manager
     *
     * @return bool
     */
    public function view(UserPolicy $user, Manager $manager)
    {
        if ($user->canDo('plan.manager.view') && $user->isAdmin()) {
            return true;
        }

        return $manager->user_id == user_id() && $manager->user_type == user_type();
    }

    /**
     * Determine if the given user can create a manager.
     *
     * @param UserPolicy $user
     * @param Manager $manager
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plan.manager.create');
    }

    /**
     * Determine if the given user can update the given manager.
     *
     * @param UserPolicy $user
     * @param Manager $manager
     *
     * @return bool
     */
    public function update(UserPolicy $user, Manager $manager)
    {
        if ($user->canDo('plan.manager.edit') && $user->isAdmin()) {
            return true;
        }

        return $manager->user_id == user_id() && $manager->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given manager.
     *
     * @param UserPolicy $user
     * @param Manager $manager
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Manager $manager)
    {
        return $manager->user_id == user_id() && $manager->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given manager.
     *
     * @param UserPolicy $user
     * @param Manager $manager
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Manager $manager)
    {
        if ($user->canDo('plan.manager.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given manager.
     *
     * @param UserPolicy $user
     * @param Manager $manager
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Manager $manager)
    {
        if ($user->canDo('plan.manager.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
