<?php

namespace Moblyze\Plan\Policies;

use Litepie\User\Contracts\UserPolicy;
use Moblyze\Plan\Models\Users;

class UsersPolicy
{

    /**
     * Determine if the given user can view the users.
     *
     * @param UserPolicy $user
     * @param Users $users
     *
     * @return bool
     */
    public function view(UserPolicy $user, Users $users)
    {
        if ($user->canDo('plan.users.view') && $user->isAdmin()) {
            return true;
        }

        return $users->user_id == user_id() && $users->user_type == user_type();
    }

    /**
     * Determine if the given user can create a users.
     *
     * @param UserPolicy $user
     * @param Users $users
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('plan.users.create');
    }

    /**
     * Determine if the given user can update the given users.
     *
     * @param UserPolicy $user
     * @param Users $users
     *
     * @return bool
     */
    public function update(UserPolicy $user, Users $users)
    {
        if ($user->canDo('plan.users.edit') && $user->isAdmin()) {
            return true;
        }

        return $users->user_id == user_id() && $users->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given users.
     *
     * @param UserPolicy $user
     * @param Users $users
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Users $users)
    {
        return $users->user_id == user_id() && $users->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given users.
     *
     * @param UserPolicy $user
     * @param Users $users
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Users $users)
    {
        if ($user->canDo('plan.users.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given users.
     *
     * @param UserPolicy $user
     * @param Users $users
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Users $users)
    {
        if ($user->canDo('plan.users.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
